package com.zg.project.Inventory.Task.service;

import java.util.List;
import com.zg.project.Inventory.domain.entity.InventoryTask;

/**
 * 盘点任务Service接口
 * 
 * @author zg
 * @date 2025-06-16
 */
public interface IInventoryTaskService 
{
    /**
     * 查询盘点任务
     * 
     * @param id 盘点任务主键
     * @return 盘点任务
     */
    public InventoryTask selectInventoryTaskById(Long id);

    /**
     * 查询盘点任务列表
     * 
     * @param inventoryTask 盘点任务
     * @return 盘点任务集合
     */
    public List<InventoryTask> selectInventoryTaskList(InventoryTask inventoryTask);

    /**
     * 新增盘点任务
     * 
     * @param inventoryTask 盘点任务
     * @return 结果
     */
    public int insertInventoryTask(InventoryTask inventoryTask);

    /**
     * 修改盘点任务
     * 
     * @param inventoryTask 盘点任务
     * @return 结果
     */
    public int updateInventoryTask(InventoryTask inventoryTask);

    /**
     * 批量删除盘点任务
     * 
     * @param ids 需要删除的盘点任务主键集合
     * @return 结果
     */
    public int deleteInventoryTaskByIds(Long[] ids);

    /**
     * 删除盘点任务信息
     * 
     * @param id 盘点任务主键
     * @return 结果
     */
    public int deleteInventoryTaskById(Long id);

    /**
     * 统计用户待处理的盘点任务数量
     * @param userId
     * @return
     */
    int countPendingTaskByUserId(Long userId);

    /**
     * 根据盘点任务id获取仓库id
     * @param taskId
     * @return
     */
    String getWhByTaskId(String taskId);
}
